==> haskell-wai-websockets-3.0.1.2-463-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-websockets.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wai-websockets
version:              3.0.1.2
visibility:           public
id:                   wai-websockets-3.0.1.2-4lyS0XS8yMm6Z96jQXlhHT
key:                  wai-websockets-3.0.1.2-4lyS0XS8yMm6Z96jQXlhHT
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Jasper Van der Jeugt, Ting-Yen Lai
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             Provide a bridge between WAI and the websockets package.
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-websockets>.

category:             Web, Yesod
abi:                  a7b470047e970195e2d44262e348d6f1
exposed:              True
exposed-modules:      Network.Wai.Handler.WebSockets
import-dirs:          /usr/lib/ghc-9.2.8/site-local/wai-websockets-3.0.1.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/wai-websockets-3.0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-websockets
hs-libraries:         HSwai-websockets-3.0.1.2-4lyS0XS8yMm6Z96jQXlhHT
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    case-insensitive-1.2.1.0-BBCkGXkqh3nGRz3m4HFNUT
    http-types-0.12.4-IbDJVwQVDeTAnHs7wyLMrJ
    network-3.1.4.0-2VaTeXEywlqHC2pV2iXMik transformers-0.5.6.2
    wai-3.2.4-BbAdcKGl4jbBaSv8iBtxy6
    websockets-0.12.7.3-68ozGwxTRHMKXaFM20A89F

haddock-interfaces:
    /usr/share/doc/haskell-wai-websockets/html/wai-websockets.haddock

haddock-html:         /usr/share/doc/haskell-wai-websockets/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-websockets-3.0.1.2-472-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-websockets.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wai-websockets
version:              3.0.1.2
visibility:           public
id:                   wai-websockets-3.0.1.2-1L4hSbNkRVN1DmSZkFeGLC
key:                  wai-websockets-3.0.1.2-1L4hSbNkRVN1DmSZkFeGLC
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Jasper Van der Jeugt, Ting-Yen Lai
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             Provide a bridge between WAI and the websockets package.
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-websockets>.

category:             Web, Yesod
abi:                  b606c57972c598d49ca785e3a0fa5fcb
exposed:              True
exposed-modules:      Network.Wai.Handler.WebSockets
import-dirs:          /usr/lib/ghc-9.2.8/site-local/wai-websockets-3.0.1.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/wai-websockets-3.0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-websockets
hs-libraries:         HSwai-websockets-3.0.1.2-1L4hSbNkRVN1DmSZkFeGLC
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    case-insensitive-1.2.1.0-6AqTtfG0yj5cd4BFV01sh
    http-types-0.12.4-4jA7skhyc4O1mTcupRz8pv
    network-3.1.4.0-BwapeZNENJRGd3a4t7iBSJ transformers-0.5.6.2
    wai-3.2.4-JIqkXCnMPAzFKNQzPpgW2q
    websockets-0.12.7.3-76PLcVimgTmIzbKQenv4SO

haddock-interfaces:
    /usr/share/doc/haskell-wai-websockets/html/wai-websockets.haddock

haddock-html:         /usr/share/doc/haskell-wai-websockets/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
